/* GFE -- GNU Font Editor
 * Copyright (C) 2000 Anuradha Ratnaweera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include <gtk/gtk.h>
#include "xpm.h"

#include "pixmaps/gfe.xpm"
#include "pixmaps/ok.xpm"

extern GtkWidget *main_window;

/* Local function declarations */

static void
about_dialog_destroy(GtkWidget *widget, gpointer data);

/* Global functions */

/* Help->about menu item handler. Displays the "About GFE" dialog box and
 * deactivates main_window. */
void
about_dialog_create(void)
{
  GtkWidget *window;
  GtkWidget *button;
  GtkWidget *label;
  GtkWidget *pixmapwid;
  GdkPixmap *pixmap;
  GdkBitmap *mask;
  GtkStyle *style;

  window = gtk_dialog_new ();

  gtk_signal_connect(GTK_OBJECT(window), "destroy",
                     GTK_SIGNAL_FUNC(about_dialog_destroy), 
		     (gpointer)window);
            
  gtk_window_set_title(GTK_WINDOW(window), "About GNU Font Editor");
  gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, FALSE); 
  gtk_container_set_border_width(GTK_CONTAINER(window), 10);
  gtk_widget_realize(window);

  button = xpm_label_button(window, ok_xpm, "Ok");
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
		     GTK_SIGNAL_FUNC(about_dialog_destroy),
		     (gpointer)window);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->action_area),
		     button, FALSE, FALSE, 0);
  gtk_widget_show(button);

  style = gtk_widget_get_style(window);
  pixmap = gdk_pixmap_create_from_xpm_d(window->window, &mask,
		                        &style->bg[GTK_STATE_NORMAL],
		                        (gchar**)gfe_xpm);
  pixmapwid = gtk_pixmap_new(pixmap, mask);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
		     pixmapwid, TRUE, TRUE, 0);
  gtk_widget_show(pixmapwid);
  
  label = gtk_label_new("\nGNU Font Editor\n"
		        "Version " VERSION "\n");
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
		     label, TRUE, TRUE, 0);
  gtk_widget_show(label);

  label = gtk_label_new("Please visit\n"
		        "http://www.gnu.org/software/gfe/gfe.html\n"
			"for more info\n");
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
		     label, TRUE, TRUE, 0);
  gtk_widget_show(label);

  label = gtk_label_new("Copyright (C) 2000 Anuradha Ratnaweera\n");
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
		     label, TRUE, TRUE, 0);
  gtk_widget_show(label);

  gtk_widget_show(window);
  gtk_widget_set_sensitive(main_window, FALSE);
}

/* Local functions */

/* Destroy event handler for the "About GFE" dialog box. */
static void
about_dialog_destroy(GtkWidget *widget, gpointer data)
{
  gtk_widget_set_sensitive(main_window, TRUE);
  gtk_widget_destroy(GTK_WIDGET(data));
}

