/* GFE -- GNU Font Editor
 * Copyright (C) 2000 Anuradha Ratnaweera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include <gtk/gtk.h>

#include "character.h"
#include "font.h"
#include "editor.h"
#include "gui.h"
#include "properties_dialog.h"

extern GtkWidget *main_window;

extern GtkWidget *drawing_area;
extern GtkWidget *statusbar;
extern guint statusbar_context_id;

extern GfeFont *first_font;
extern GfeFont *last_font;
extern GfeFont *current_font;

/* Global functions */

/* Event handler for character->new menu item. */
void
char_new_callback(void)
{
  if (current_font == NULL) return;
  if (current_font->current_glyph == NULL) return;

  /* FIXME: create new glyph */
}

/* Event handler for character->next menu item. */
void
char_next_callback(void)
{
  if (current_font == NULL) return;
  if (current_font->current_glyph == NULL) return;

  set_current_glyph_pre();

  if (current_font->current_glyph == current_font->last_glyph){
    current_font->current_glyph = current_font->first_glyph;
  }
  else {
    current_font->current_glyph = current_font->current_glyph->next;
  }

  set_current_glyph_post();
}

/* Event handler for character->previous menu item. */
void
char_previous_callback(void)
{
  if (current_font == NULL) return;
  if (current_font->current_glyph == NULL) return;

  set_current_glyph_pre();

  if (current_font->current_glyph == current_font->first_glyph){
    current_font->current_glyph = current_font->last_glyph;
  }
  else {
    current_font->current_glyph = current_font->current_glyph->previous;
  }

  set_current_glyph_post();
}

/* Event handler for character->next_font menu item. */
void
font_next_callback(void)
{
  if (current_font == NULL) return;

  set_current_glyph_pre();

  if (current_font == last_font){
    current_font = first_font;
  }
  else {
    current_font = current_font->next;
  }

  set_current_glyph_post();

  status_bar_set_string(current_font->filename);
  set_title();
}

/* Event handler for character->previous_font menu item. */
void
font_previous_callback(void)
{
  if (current_font == NULL) return;

  set_current_glyph_pre();

  if (current_font == first_font){
    current_font = last_font;
  }
  else {
    current_font = current_font->previous;
  }

  set_current_glyph_post();
  status_bar_set_string(current_font->filename);
  set_title();
}

/* Character->font properties event handler */
void
font_properties_callback(void)
{
  if (current_font == NULL)
    return;
  font_properties_dialog_create();
}

