/* GFE -- GNU Font Editor
 * Copyright (C) 2000 Anuradha Ratnaweera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GFE_FONT_H__
#define __GFE_FONT_H__

#include <gtk/gtk.h>

#include "glyph.h"

/* macro for type casting */

#define GFE_FONT(font) ((GfeFont*)(font))

/* font types */

#define FONT_TYPE_NONE     0
#define FONT_TYPE_RASTER   1

/* font file formats */

#define FONT_FORMAT_NONE   0
#define FONT_FORMAT_BDF21  1
#define FONT_FORMAT_BDF22  2

/* macros to access members of GfeFont structure */

#define GFE_FONT_TYPE(font)            (((font)->flags) & 0x000000ff)

/* GfeFont is the generic font type from which all the other font
 * types are derived. */

typedef struct _GfeFont GfeFont;

struct _GfeFont {
  /* first 8 bits of flags will be used for font type */
  guint32 flags;
  int format;
  char *name;
  char *filename;
  char *content_version;
  int num_glyphs;
  GfeGlyph *first_glyph;
  GfeGlyph *last_glyph;
  GfeGlyph *current_glyph;
  GfeFont *next;
  GfeFont *previous;
};

/* global function declarations */

void gfe_font_init(GfeFont *font);
void gfe_font_set_type(GfeFont *font, guint8 type);
int gfe_font_set_name(GfeFont *font, char *name);
int gfe_font_set_filename(GfeFont *font, char *name);
int gfe_font_set_content_version(GfeFont *font, char *content_version);
void gfe_font_free(GfeFont *font);
void gfe_font_add_glyph(GfeFont *font, GfeGlyph *glyph);

#endif /* !__GFE_FONT_H__ */
