/* GFE -- GNU Font Editor
 * Copyright (C) 2000 Anuradha Ratnaweera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include <gtk/gtk.h>
#include <malloc.h>

#include "auxil.h"
#include "glyph.h"

/* global functions */

/* Initializes glyph that is already allocated. Should not be called
 * directly. Instead routines that create derived types from GfeGlyph
 * should call this just after creating a pointer to the derived type.
 * See structures.txt. */
void
gfe_glyph_init(GfeGlyph *glyph)
{
  glyph->name = NULL;
  glyph->encoding = GFE_GLYPH_NO_ENCODING;
  glyph->next = NULL;
  glyph->previous = NULL;
}

/* Sets the 8 least significant bits of the flags to type. */
void
gfe_glyph_set_type(GfeGlyph *glyph, guint8 type)
{
  glyph->flags &= 0xffffff00;
  glyph->flags |= type;
}

/* Sets the name of the glyph to name. Returns zero on success, nonzero
 * on failure. */
int
gfe_glyph_set_name(GfeGlyph *glyph, char *name)
{
  return(string_copy(name, &(glyph->name)));
}

/* Clears dynamically allocated memory of a glyph. See structures.txt*/
void
gfe_glyph_free(GfeGlyph *glyph)
{
  free(glyph->name);
}

