/* GFE -- GNU Font Editor
 * Copyright (C) 2000 Anuradha Ratnaweera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include "auxil.h"
#include "character.h"
#include "file.h"
#include "font.h"
#include "raster_glyph.h"
#include "toolbar.h"

/* Global variables */

extern GfeGlyph *current_glyph;

/* Local variables */

/* The glyph toolbar */
static GtkWidget *glyph_toolbar;

/* drawing area and backing pixmap */
static GtkWidget *sm_drawing_area;
static GdkPixmap *sm_pixmap = NULL;

/* offset of the current glyph in drawing area */
static int x_off, y_off;

/* Local function declarations */
static gint sm_expose_event(GtkWidget *widget, GdkEventExpose *event);
static gint sm_configure_event(GtkWidget *widget, GdkEventExpose *event);
static gint sm_draw_glyph(GtkWidget *widget);

/* Global functions */

/* Creates a toolbar to set individual glyph properties. Shows
 * all the child widgets, but not the toolbar itself. */
GtkWidget
*create_glyph_toolbar(GtkWidget *window)
{
  GtkWidget *vbox;
  GtkWidget *label;

  glyph_toolbar = gtk_vbox_new(FALSE, 2);

  vbox = gtk_vbox_new(FALSE, 5);
  gtk_box_pack_start(GTK_BOX(glyph_toolbar), vbox, FALSE, FALSE, 0);
  gtk_widget_show(vbox);

  /* name , encoding , glyph */
  label = gtk_label_new(NULL);
  gtk_object_set_data(GTK_OBJECT(glyph_toolbar), "encoding_text",
		      (gpointer)label);
  gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
  gtk_widget_show(label);

  label = gtk_label_new(NULL);
  gtk_object_set_data(GTK_OBJECT(glyph_toolbar), "encoding",
		      (gpointer)label);
  gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
  gtk_widget_show(label);

  label = gtk_label_new(NULL);
  gtk_object_set_data(GTK_OBJECT(glyph_toolbar), "name_text",
		      (gpointer)label);
  gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
  gtk_widget_show(label);

  label = gtk_label_new(NULL);
  gtk_object_set_data(GTK_OBJECT(glyph_toolbar), "name",
		      (gpointer)label);
  gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
  gtk_widget_show(label);

  sm_drawing_area = gtk_drawing_area_new();  
  gtk_object_set_data(GTK_OBJECT(glyph_toolbar), "sm_drawing_area",
		      (gpointer)sm_drawing_area);
  gtk_drawing_area_size(GTK_DRAWING_AREA(sm_drawing_area), 0, 30);
  gtk_signal_connect(GTK_OBJECT(sm_drawing_area), "expose_event",
		     GTK_SIGNAL_FUNC(sm_expose_event), NULL);
  gtk_signal_connect(GTK_OBJECT(sm_drawing_area), "configure_event",
		     GTK_SIGNAL_FUNC(sm_configure_event), NULL);
  gtk_box_pack_start(GTK_BOX(vbox), sm_drawing_area, TRUE, TRUE, 0);
  gtk_widget_show(sm_drawing_area);

  return (glyph_toolbar);
}

void
glyph_toolbar_set()
{
  GtkWidget *label;
  GtkWidget *widget;
  gchar *str;
  gboolean glyph_drawn = FALSE;
  
  /* Check if label texts have to be freed first */

  if (current_glyph) {
    if (glyph_drawn == FALSE) {
      label = gtk_object_get_data(GTK_OBJECT(glyph_toolbar),
		                  "encoding_text");
      gtk_label_set_text(GTK_LABEL(label), "Encoding");

      label = gtk_object_get_data(GTK_OBJECT(glyph_toolbar),
		                  "name_text");
      gtk_label_set_text(GTK_LABEL(label), "Name");

      glyph_drawn = TRUE;
    }

    label = gtk_object_get_data(GTK_OBJECT(glyph_toolbar), "encoding");
    str = g_strdup_printf("%d\n(0x%02X)\n", current_glyph->encoding,
		          current_glyph->encoding);
    gtk_label_set_text(GTK_LABEL(label), str);
    g_free(str);

    label = gtk_object_get_data(GTK_OBJECT(glyph_toolbar), "name");
    str = g_strdup_printf("%s\n", current_glyph->name);
    gtk_label_set_text(GTK_LABEL(label), str);
    g_free(str);

    while (gtk_events_pending())
      gtk_main_iteration();
    widget = gtk_object_get_data(GTK_OBJECT(glyph_toolbar),
		                 "sm_drawing_area");
    sm_draw_glyph(widget);
  }
  else {
    label = gtk_object_get_data(GTK_OBJECT(glyph_toolbar),
		                "encoding_text");
    gtk_label_set_text(GTK_LABEL(label), NULL);

    label = gtk_object_get_data(GTK_OBJECT(glyph_toolbar), "encoding");
    gtk_label_set_text(GTK_LABEL(label), NULL);

    label = gtk_object_get_data(GTK_OBJECT(glyph_toolbar),
		                "name_text");
    gtk_label_set_text(GTK_LABEL(label), NULL);

    label = gtk_object_get_data(GTK_OBJECT(glyph_toolbar), "name");
    gtk_label_set_text(GTK_LABEL(label), NULL);

    glyph_drawn = FALSE;
  }
}

/* Sets the colour of a pixel in the glyph in the glyph toolbar
 * it BLACK is TURE, it is coloured in black, otherwise in white. */
void
sm_color_box(int col, int row, int black)
{
  GdkRectangle update_rect;

  if (sm_pixmap == NULL) return; 

  update_rect.x = x_off + col;
  update_rect.y = y_off + row;
  update_rect.width = 1;
  update_rect.height = 1;

  if (black){
    gdk_draw_point(sm_pixmap, sm_drawing_area->style->black_gc,
                   update_rect.x, update_rect.y);
  }
  else {
    gdk_draw_point(sm_pixmap, sm_drawing_area->style->white_gc,
                   update_rect.x, update_rect.y);
  }

  gtk_widget_draw(sm_drawing_area, &update_rect);
}

/* Local functions */

/* Exposet_event handler of sm_drawing_area. Just copies from pixmap to
 * sm_drawing_area. */
static gint
sm_expose_event(GtkWidget *widget, GdkEventExpose *event)
{
  if (sm_pixmap == NULL)
    return FALSE;

  gdk_draw_pixmap(widget->window,
                  widget->style->bg_gc[GTK_WIDGET_STATE(widget)],
	          sm_pixmap, event->area.x, event->area.y,
                  event->area.x, event->area.y,
                  event->area.width, event->area.height);
  return FALSE;
}

/* Configure_event handler of sm_drawing_area. Just copies from pixmap to
 * drawing_area. */
static gint
sm_configure_event(GtkWidget *widget, GdkEventExpose *event)
{
  if (current_glyph == NULL)
    return 0;

  if (sm_pixmap)
    gdk_pixmap_unref(sm_pixmap);

  sm_pixmap = gdk_pixmap_new(widget->window, widget->allocation.width,
		             widget->allocation.height, -1);
  sm_draw_glyph(widget);

  return TRUE;
}

/* Draws the current_glyph on the pixmap */
static gint
sm_draw_glyph(GtkWidget *widget)
{
  int x_max, y_max;
  int col, row;
  GdkRectangle update_rect;

  if (current_glyph == NULL)
    return FALSE;

  if (sm_pixmap == NULL){
    sm_pixmap = gdk_pixmap_new(widget->window, widget->allocation.width,
		               widget->allocation.height, -1);
  }

  gdk_draw_rectangle(sm_pixmap, widget->style->bg_gc[GTK_WIDGET_STATE(widget)],
		     TRUE, 0, 0,
		     widget->allocation.width,
		     widget->allocation.height);

  switch (GFE_GLYPH_TYPE(current_glyph)){
    case FONT_TYPE_RASTER:
      x_max = GFE_RASTER_GLYPH(current_glyph)->bitmap->width;
      y_max = GFE_RASTER_GLYPH(current_glyph)->bitmap->height;
      x_off = (widget->allocation.width - x_max) / 2;
      y_off = 0;
      gdk_draw_rectangle(sm_pixmap, widget->style->white_gc,
		         TRUE, x_off, y_off,
			 x_max, y_max);
      for (col = 0; col < x_max; col++){
        for (row = 0; row < y_max; row++){
	  if (gfe_bitmap_get_bit(GFE_RASTER_GLYPH(current_glyph)->bitmap,
				 col, row))
	    gdk_draw_point(sm_pixmap, widget->style->black_gc,
			   col + x_off, row + y_off);
	}
      }
  }
  update_rect.x = 0;
  update_rect.y = 0;
  update_rect.width = widget->allocation.width;
  update_rect.height = widget->allocation.height;
  gtk_widget_draw(widget, &update_rect);

  while (gtk_events_pending())
    gtk_main_iteration();

  return FALSE;
}


