/* GFE -- GNU Font Editor
 * Copyright (C) 2000 Anuradha Ratnaweera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include <gtk/gtk.h>
#include "init.h"

/*
 * argv processing:
 *
 *   Arguments that are not switches are considered as font
 *   files.
 *
 *   The GTK switches are processed first (X switches are processed
 *   here, not by any X routines).
 * 
 */

int
main(int argc, char *argv[])
{
  int show_version;
  int show_help;
  int i;

  /* process gtk/X switches */
  gtk_init(&argc, &argv);

  show_version = FALSE;
  show_help = FALSE;

  for (i = 1; i < argc; i++) {
    if ((strcmp(argv[i], "--version") == 0) || 
        (strcmp(argv[i], "-v") == 0)) {
      show_version = TRUE;
    }
    else if ((strcmp(argv[i], "--help") == 0) || 
             (strcmp(argv[i], "-h") == 0)) {
      show_help = TRUE;
    }
    /* anything else that start with - is an error */
    else if (argv[i][0] == '-') {
      show_help = TRUE;
    }
  }

  if (show_version) {
    g_print("GFE - GNU Font Editor " VERSION "\n");
  }

  if (show_help) {
    g_print("Usage: gfe [option ...] [files ...]\n");
    g_print("Valid options are:\n");
    g_print("  -h --help              Output this help.\n");
    g_print("  -v --version           Output version information.\n");
    g_print("\n");
    g_print("Report bugs to bug-gfe@gnu.org\n");
  }

  if (show_version || show_help)
    exit (0);

  if (!gfe_init(argc - 1, argv + 1))
    gtk_main();

  return(0);
}

