/* GFE -- GNU Font Editor
 * Copyright (C) 2000 Anuradha Ratnaweera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include <gtk/gtk.h>
#include "about_dialog.h"
#include "character.h"
#include "file.h"
#include "font.h"
#include "gui.h"
#include "menu.h"

/* menu items */
static GtkItemFactoryEntry menu_items[] = 
{
  {"/_File", NULL, NULL, 0, "<Branch>"},
  {"/File/_Open...", "<control>O", file_open_callback, 0, NULL},
  {"/File/_Save", "<control>S", file_save_callback, 0, NULL},
  {"/File/Save _As...", NULL, file_save_as_callback, 0, NULL},
  {"/File/_Close","<control>W", file_close_callback, 0, NULL},
  {"/File/---",   NULL, NULL, 0, "<Separator>"},
  {"/File/_Quit", "<control>Q", destroy_callback, 0, NULL},
  {"/_Character", NULL, NULL, 0, "<Branch>"},
  {"/Character/_Next", "N", char_next_callback, 0, NULL},
  {"/Character/_Previous", "P", char_previous_callback, 0, NULL},
  {"/Character/Ne_xt Font", "<control>N", font_next_callback, 0, NULL},
  {"/Character/P_revious Font", "<control>P", font_previous_callback, 0, NULL},
  {"/Character/Font Proper_ties...", NULL, font_properties_callback, 0, NULL},
  {"/_Help", NULL, NULL, 0, "<Branch>"},
  {"/Help/_About...", NULL, about_dialog_create, 0, NULL}
};

/* global functions */

/* Creates the main menu bar, set event handlers and returns a pointer
 * to it. All the child widgets are shown, but not the menu_bar itself.
 * Should be changed in a future version to use itemfactory. */
GtkWidget
*create_menu_bar(GtkWidget *window)
{  
  GtkWidget *menu_bar;
  GtkItemFactory *item_factory;
  GtkAccelGroup *accel_group;
  gint num_menu_items;

  num_menu_items = sizeof(menu_items) / sizeof(menu_items[0]);

  accel_group = gtk_accel_group_new();
  item_factory = gtk_item_factory_new(GTK_TYPE_MENU_BAR, "<main>",
		                      accel_group);
  gtk_item_factory_create_items(item_factory, num_menu_items, menu_items, NULL);
  gtk_accel_group_attach(accel_group, GTK_OBJECT(window));
  menu_bar = gtk_item_factory_get_widget(item_factory, "<main>");

  return(menu_bar);
}

