/* GFE -- GNU Font Editor
 * Copyright (C) 2000 Anuradha Ratnaweera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gtk/gtk.h>
#include "font.h"
#include "xpm.h"

#include "pixmaps/ok.xpm"
#include "pixmaps/cancel.xpm"

extern GtkWidget *main_window;

extern GfeFont *current_font;

/* Local function declarations */
static void font_properties_dialog_destroy(GtkWidget *widget, gpointer data);
static void font_properties_dialog_ok(GtkWidget *widget, gpointer data);


/* Global functions */

/* Create the "font properties" dialog, sets it's callbacks and disables
 * main window. */
void
font_properties_dialog_create(void)
{
  GtkWidget *window;
  GtkWidget *button;
  GtkWidget *label;
  GtkWidget *hbox;
  GtkWidget *text_entry;

  if (current_font == NULL)
    return;

  window = gtk_dialog_new();

  gtk_signal_connect(GTK_OBJECT(window), "destroy",
		     GTK_SIGNAL_FUNC(font_properties_dialog_destroy),
		     window);

  gtk_window_set_title(GTK_WINDOW(window), "Font properties");
  gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, FALSE); 
  gtk_container_set_border_width(GTK_CONTAINER (window), 10);
  gtk_widget_realize(window);

  button = xpm_label_button(window, ok_xpm, "Apply");
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
		     GTK_SIGNAL_FUNC(font_properties_dialog_ok),
		     (gpointer)window);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->action_area),
		     button, FALSE, FALSE, 0);
  gtk_widget_show(button);

  button = xpm_label_button(window, cancel_xpm, "Cancel");
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
		     GTK_SIGNAL_FUNC(font_properties_dialog_destroy),
		     (gpointer)window);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->action_area),
		     button, FALSE, FALSE, 0);
  gtk_widget_show(button);

  /* font name text entry */
  /* consider the use of a table here - check gimp source */
  hbox = gtk_hbox_new(FALSE, 0);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
		     hbox, FALSE, FALSE, 0);
  gtk_widget_show(hbox);

  label = gtk_label_new("Font name ");
  gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
  gtk_widget_show(label);

  text_entry = gtk_entry_new();
  gtk_box_pack_start(GTK_BOX(hbox), text_entry, FALSE, FALSE, 0);
  gtk_entry_set_text(GTK_ENTRY(text_entry), current_font->name);
  gtk_object_set_data(GTK_OBJECT(window), "font_name",
		      (gpointer)text_entry);
  gtk_widget_show(text_entry);
  
  /* FIXME the font name should be divided and appear as many
   * text boxes instead of a single text box. */

  gtk_widget_show(window);
  gtk_widget_set_sensitive(main_window, FALSE);
}

/* Destroy event handler of the properties box. */
static void
font_properties_dialog_destroy(GtkWidget *widget, gpointer data)
{
  gtk_widget_set_sensitive(main_window, TRUE);
  gtk_widget_destroy(GTK_WIDGET(data));
}

/* Apply button press handler of the properties box. */
static void
font_properties_dialog_ok(GtkWidget *widget, gpointer data)
{
  GtkWidget *text_entry;

  text_entry = gtk_object_get_data(GTK_OBJECT(data), "font_name");
  gfe_font_set_name(current_font, gtk_entry_get_text(GTK_ENTRY(text_entry)));

  gtk_widget_set_sensitive(main_window, TRUE);
  gtk_widget_destroy(GTK_WIDGET(data));
}

