/* GFE -- GNU Font Editor
 * Copyright (C) 2000 Anuradha Ratnaweera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include <malloc.h>

#include "auxil.h"
#include "bitmap.h"
#include "font.h"
#include "raster_font.h"

/* global functions */

/* Creates a GfeRasterFont structure and returns a pointer to it.
 * Returns NULL in case of a failure. See structures.txt */
GfeRasterFont*
gfe_raster_font_new(void)
{
  GfeRasterFont *font;

  font = malloc(sizeof(GfeRasterFont));

  gfe_font_init(GFE_FONT(font));
  
  gfe_font_set_type(GFE_FONT(font), FONT_TYPE_RASTER);

  GFE_RASTER_FONT(font)->point_size = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->x_resolution = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->y_resolution = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->bbx_width = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->bbx_height = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->bbx_x_offset = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->bbx_y_offset = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->metricsset = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->sw_x = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->sw_y = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->dw_x = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->dw_y = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->sw1_x = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->sw1_y = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->dw1_x = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->dw1_y = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->vv_x = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->vv_y = GFE_UNDEFINED;
  GFE_RASTER_FONT(font)->num_properties = 0;
  GFE_RASTER_FONT(font)->property = NULL;
  GFE_RASTER_FONT(font)->value = NULL;
  
  return (font);
}

/* Clears dynamically allocated memory of font. See structures.txt. */
void
gfe_raster_font_free(GfeRasterFont *font)
{
  int i;

  gfe_font_free(GFE_FONT(font));

  for (i = 0; i < GFE_RASTER_FONT(font)->num_properties; i++){
    free(GFE_RASTER_FONT(font)->property[i]);
    free(GFE_RASTER_FONT(font)->value[i]);
  }
  free(GFE_RASTER_FONT(font)->property);
  free(GFE_RASTER_FONT(font)->value);

  GFE_RASTER_FONT(font)->property = NULL;
  GFE_RASTER_FONT(font)->value = NULL;
}

/* Clears the dynamically allocated memory of font and destroys it.
 * See structures.txt. */
void
gfe_raster_font_destroy(GfeRasterFont *font)
{
  gfe_font_free(GFE_FONT(font));
  gfe_raster_font_free(font);
  free(font);
}

