/* GFE -- GNU Font Editor
 * Copyright (C) 2000 Anuradha Ratnaweera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include "auxil.h"
#include "character.h"
#include "file.h"
#include "toolbar.h"
#include "xpm.h"

#include "pixmaps/file_open.xpm"
#include "pixmaps/file_save.xpm"
#include "pixmaps/file_close.xpm"
#include "pixmaps/char_next.xpm"
#include "pixmaps/char_prev.xpm"

/* global functions */

/* Creates the main toolbar of GFE and returns a pointer to it. Shows
 * all the child widgets, but not the toolbar itself. */
GtkWidget
*create_main_toolbar(GtkWidget *window)
{
  GtkWidget *toolbar;
  GtkTooltips *tooltips;
  GtkWidget *button;

  toolbar = gtk_hbox_new(FALSE, 2);

  tooltips = gtk_tooltips_new();
  button = xpm_button(window, fileopen_xpm);
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
		     GTK_SIGNAL_FUNC(file_open_callback), NULL);
  gtk_widget_show(button);
  gtk_box_pack_start(GTK_BOX(toolbar), button, FALSE, FALSE, 0);
  gtk_tooltips_set_tip(tooltips, button, "Open file", NULL);

  /* find a way to use a single tooltip */
  tooltips = gtk_tooltips_new();
  button = xpm_button(window, filesave_xpm);
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
		     GTK_SIGNAL_FUNC(file_save_callback), NULL);
  gtk_widget_show(button);
  gtk_box_pack_start(GTK_BOX(toolbar), button, FALSE, FALSE, 0);
  gtk_tooltips_set_tip(tooltips, button, "Save file", NULL);

  tooltips = gtk_tooltips_new();
  button = xpm_button(window, fileclose_xpm);
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
		     GTK_SIGNAL_FUNC(file_close_callback), NULL);
  gtk_widget_show(button);
  gtk_box_pack_start(GTK_BOX(toolbar), button, FALSE, FALSE, 0);
  gtk_tooltips_set_tip(tooltips, button, "Close file", NULL);
  
  tooltips = gtk_tooltips_new();
  button = xpm_button(window, charprev_xpm);
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
		     GTK_SIGNAL_FUNC(char_previous_callback), NULL);
  gtk_widget_show(button);
  gtk_box_pack_start(GTK_BOX(toolbar), button, FALSE, FALSE, 0);
  gtk_tooltips_set_tip(tooltips, button, "Previous character", NULL);
  
  tooltips = gtk_tooltips_new();
  button = xpm_button(window, charnext_xpm);
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
		     GTK_SIGNAL_FUNC(char_next_callback), NULL);
  gtk_widget_show(button);
  gtk_box_pack_start(GTK_BOX(toolbar), button, FALSE, FALSE, 0);
  gtk_tooltips_set_tip(tooltips, button, "Next character", NULL);

  gtk_tooltips_enable(tooltips);
  
  return (toolbar);
}

